@@ -22,15 +22,6 @@ from datetime import datetime, date
 from xml.etree.ElementTree import SubElement
 
 import rb
-from gi.repository import GLib
-from gi.repository import GObject
-from gi.repository import Gdk
-from gi.repository import GdkPixbuf
-from gi.repository import Gio
-from gi.repository import Gtk
-from gi.repository import Pango
-from gi.repository import RB
-
 from alttoolbar_controller import AltAndroidController
 from alttoolbar_controller import AltCoverArtBrowserController
 from alttoolbar_controller import AltCoverArtPlaySourceController
@@ -50,8 +41,15 @@ from alttoolbar_preferences import GSetting
 from alttoolbar_rb3compat import gtk_version
 from alttoolbar_repeat import Repeat
 from alttoolbar_sidebar import AltToolbarSidebar
-from alttoolbar_widget import SmallProgressBar
-from alttoolbar_widget import SmallScale
+from alttoolbar_widget import Slider
+from gi.repository import GLib
+from gi.repository import GObject
+from gi.repository import Gdk
+from gi.repository import GdkPixbuf
+from gi.repository import Gio
+from gi.repository import Gtk
+from gi.repository import Pango
+from gi.repository import RB
 
 
 class AT(object):
@@ -734,15 +732,7 @@ class AltToolbarShared(AltToolbarBase):
         if self.plugin.inline_label:
             self.song_box.remove(self.song_button_label)
 
-        if self.plugin.compact_progressbar:
-            self.song_progress = SmallProgressBar()
-        else:
-            self.song_progress = SmallScale()
-
-        self.song_progress.set_sensitive(False)
-
-        self.song_progress.connect('control', self._sh_progress_control)
-        self.song_progress.show_all()
+        self.song_progress = Slider(self.shell.props.shell_player)
         self.song_progress_box.pack_start(self.song_progress, False, True, 1)
 
         # Bring Builtin Actions to plugin
@@ -1220,16 +1210,6 @@ class AltToolbarShared(AltToolbarBase):
         del self.__builder_obj_names
 
     # Signal Handlers
-    # ##########################################################
-
-    def _sh_progress_control(self, progress, fraction):
-        # if not hasattr(self, 'song_duration'):
-        #    return
-
-        if (self.plugin.song_duration != 0):
-            player = self.shell.props.shell_player
-            player.set_playing_time(self.plugin.song_duration * fraction)
-
     def _sh_bigger_cover(self, cover, x, y, key, tooltip):
         return self.show_cover_tooltip(tooltip)
 
@@ -1433,12 +1413,14 @@ class AltToolbarHeaderBar(AltToolbarShared):
         if not song_label:
             self.library_song_radiobutton.set_label(_('Songs'))
         else:
-            self.library_song_radiobutton.set_label(cl.get_translation(song_label))
+            self.library_song_radiobutton.set_label(
+                cl.get_translation(song_label))
 
         if not category_label:
             self.library_browser_radiobutton.set_label(_('Categories'))
         else:
-            self.library_browser_radiobutton.set_label(cl.get_translation(category_label))
+            self.library_browser_radiobutton.set_label(
+                cl.get_translation(category_label))
 
         cl.switch_locale(cl.Locale.RB)
 
@@ -1447,7 +1429,8 @@ class AltToolbarHeaderBar(AltToolbarShared):
         if not self.setup_completed:
             return
 
-        controlled, current_controller = self.is_controlled(self.shell.props.selected_page)
+        controlled, current_controller = self.is_controlled(
+            self.shell.props.selected_page)
         current_controller.set_library_labels()
 
         if toggle_button:
@@ -1521,7 +1504,6 @@ class AltToolbarHeaderBar(AltToolbarShared):
         view_name = _("Categories")
         self.library_browser_radiobutton.set_label(view_name)
 
-        default = Gtk.Settings.get_default()
         self.headerbar = Gtk.HeaderBar.new()
         self.headerbar.set_show_close_button(True)
 
@@ -1547,7 +1529,10 @@ class AltToolbarHeaderBar(AltToolbarShared):
         source_button.set_action_name("app.ToggleSourceMediaToolbar")
 
         symbol = "view-more-horizontal-symbolic"
-        source_button.set_margin_left(3)
+        if gtk_version() >= 3.14:
+            source_button.set_margin_start(6)
+        else:
+            source_button.set_margin_left(6)
 
         image = Gtk.Image.new_from_icon_name(symbol,
                                              Gtk.IconSize.SMALL_TOOLBAR)
@@ -1562,10 +1547,10 @@ class AltToolbarHeaderBar(AltToolbarShared):
         menu_button = Gtk.MenuButton.new()
         if gtk_version() >= 3.14:
             symbol = "open-menu-symbolic"
-            menu_button.set_margin_start(3)
+            menu_button.set_margin_start(6)
         else:
             symbol = "emblem-system-symbolic"
-            menu_button.set_margin_left(3)
+            menu_button.set_margin_left(6)
 
         image = Gtk.Image.new_from_icon_name(symbol,
                                              Gtk.IconSize.SMALL_TOOLBAR)
@@ -1573,7 +1558,7 @@ class AltToolbarHeaderBar(AltToolbarShared):
         menu = self.shell.props.application.get_shared_menu('app-menu')
         menu_button.set_menu_model(menu)
         self._end_box_controls.add(menu_button)
-        menu.remove(3) # help about quit
+        menu.remove(3)  # help about quit
 
         cl.switch_locale(cl.Locale.RB)
         appmenu = Gio.Menu.new()
